Generation Functions
====================

.. include:: ../../README.rst
    :start-after: before_examples_rst_tag

.. IMPORTANT::
  See the API for generation functions :ref:`here<api_gen_f>`.

.. toctree::
   :maxdepth: 2
   :caption: Documented Example Generator Functions:

   sampling
   aposmm
   uniform_or_localopt
   tasmanian
   fd_param_finder
   surmise

.. _`libEnsemble Community Repository`: https://github.com/Libensemble/libe-community-examples
